@@ -35,7 +35,11 @@ class TestRelationships(TestCase):
         self.Category = Category
 
     def test_nullify_relation(self):
+        self.CategoryTranslation = self.Category.__translatable__['class']
         article = self.Article()
         article.content = u'Some content'
-        article.categories[0] = self.Category()
+        article.categories.append(self.Category())
         self.session.commit()
+        article.categories = []
+        self.session.commit()
+        assert not self.session.query(self.CategoryTranslation).count()
